`pyqtorch` exposes three API endpoints called `run`, `sample` and `expectation`.
Please note that all endpoints expect a `QuantumCircuit` object.

# run
::: pyqtorch.api.run

# sample
::: pyqtorch.api.sample

# expectation
::: pyqtorch.api.expectation
